@@ -10,7 +10,7 @@ use Carp qw( croak carp );
 use File::ShareDir ();
 
 # ABSTRACT: Tiny C Compiler for FFI
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 
 sub _dlext ()
@@ -213,7 +213,7 @@ sub detect_sysinclude_path
     require File::Spec;
     
     push @path_list, File::Spec->catdir(Alien::TinyCC->libtcc_library_path, qw( tcc include ));
-    push @path_list, @lines;
+    push @path_list, map { chomp; s/^ //; $_ } @lines;
   }    
   else
   {
@@ -371,7 +371,7 @@ FFI::TinyCC - Tiny C Compiler for FFI
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -412,6 +412,10 @@ For code that requires system headers:
      puts("hello world");
    }
  });
+ 
+ my $address = $tcc->get_symbol('print_hello');
+ attach [$address => 'print_hello'] => [] => void;
+ print_hello();
 
 =head1 DESCRIPTION
 
